@@ -49,7 +49,9 @@ class Backup(base_api_core.Core):
         api_name = 'SYNO.Backup.Task'
         info = self.gen_list[api_name]
         api_path = info['path']
-        req_param = {'version': info['minVersion'], 'method': 'status', 'blOnline': 'false', 'additional': '["last_bkp_time","next_bkp_time","last_bkp_result","is_modified","last_bkp_progress"]', 'task_id': taskid}
+        req_param = {'version': info['minVersion'], 'method': 'status', 'blOnline': 'false',
+                     'additional': '["last_bkp_time","next_bkp_time","last_bkp_result","is_modified","last_bkp_progress"]',
+                     'task_id': taskid}
 
         return self.request_data(api_name, api_path, req_param)
 
