@@ -25,6 +25,7 @@ class OAuth(base_api_core.Core):
         api_name = 'SYNO.OAUTH.Log'
         info = self.gen_list[api_name]
         api_path = info['path']
-        req_param = {'version': info['maxVersion'], 'method': 'list', 'action': 'list', 'offset': offset, 'limit': limit}
+        req_param = {'version': info['maxVersion'], 'method': 'list', 'action': 'list',
+                     'offset': offset, 'limit': limit}
 
         return self.request_data(api_name, api_path, req_param)
