@@ -12,6 +12,9 @@ class UniversalSearch:
 		self._sid = self.session.sid
 		self.base_url = self.session.base_url
 
+	def logout(self):
+		self.session.logout('FileStation')
+
 	def search(self, keyword):
 		api_name = 'SYNO.Finder.FileIndexing.Search'
 		info = self.finder_list[api_name]
